@@ -1,6 +1,7 @@
-#' Export a dendrogram object to text.
+#' Write a dendrogram object to parenthetic text.
 #'
-#' This function writes a dendrogram object to Newick-style parenthetic text.
+#' This function exports a dendrogram object as a Newick/New Hampshire
+#'   text string.
 #'
 #' @param x an object of class \code{"dendrogram"}.
 #' @param file a character string naming a file or connection to write the
@@ -13,26 +14,29 @@
 #'   included in the output string.
 #' @param ... further arguments to be passed to \code{format}. Used to
 #'   specify the numbering style of the edge weights (if edges = TRUE).
-#' @seealso \code{\link{read.dendrogram}} to create a \code{"dendrogram"}
+#' @seealso \code{\link{read.dendrogram}} to parse a \code{"dendrogram"}
 #'   object from a text file.
 #'   The \code{\link[ape]{write.tree}} function in the \code{\link[ape]{ape}}
 #'   package performs a similar operation for \code{"phylo"}
 #'   and \code{"multiPhylo"} objects.
+#' @references
+#'   Felsenstein J (1986) The Newick tree format.
+#'   \url{http://evolution.genetics.washington.edu/phylip/newicktree.html}
+#'
+#'   Olsen G (1990) Interpretation of the "Newick's 8:45" tree format standard.
+#'   \url{http://evolution.genetics.washington.edu/phylip/newick_doc.html}
 #' @examples
 #'   newick <- "(A:0.1,B:0.2,(C:0.3,D:0.4):0.5);"
 #'   x <- read.dendrogram(text = newick)
 #'   write.dendrogram(x, edges = TRUE)
 ################################################################################
 write.dendrogram <- function(x, file = "", append = FALSE, edges = TRUE, ...){
-  if(!(inherits(x, "dendrogram"))) stop("Input object must be of class
-                                        'dendrogram'")
+  if(!(inherits(x, "dendrogram"))) stop("Input object must be a dendrogram")
   renameLeaves <- function(y){
     if(is.leaf(y)){
       tmp <- attr(y, "label")
-      if(grepl("[^abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789]",
-               tmp)){
-        tmp <- paste0(c("'", tmp, "'"), collapse = "")
-      }
+      pa <- "[^abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789]"
+      if(grepl(pa, tmp)) tmp <- paste0(c("'", tmp, "'"), collapse = "")
       y[1] <- tmp
     }
     y
@@ -70,8 +74,10 @@ write.dendrogram <- function(x, file = "", append = FALSE, edges = TRUE, ...){
   tmp <- gsub("edge=\"([-0-9Ee.]+)\"", "edge=\\1", tmp)
   tmp2 <- gsub("list", ";", tmp) # needs to be a special single char
   while(grepl("structure", tmp2)){
-    tmp2 <- gsub("structure\\(\"([^\"]*)\",edge=([-0-9Ee.]+)\\)", "\\1:\\2", tmp2)
-    tmp2 <- gsub(";\\(([^;\\)]*)\\)", "\"openbracket\\1closebracket\"", tmp2)
+    tmp2 <- gsub(
+      "structure\\(\"([^\"]*)\",edge=([-0-9Ee.]+)\\)", "\\1:\\2", tmp2)
+    tmp2 <- gsub(
+      ";\\(([^;\\)]*)\\)", "\"openbracket\\1closebracket\"", tmp2)
   }
   tmp3 <- gsub("openbracket", "\\(", tmp2)
   tmp3 <- gsub("closebracket", "\\)", tmp3)
